@@ -7,7 +7,7 @@ knitr::opts_chunk$set(
   fig.width = 8,
   fig.height = 6,
   dpi = 80,
-  eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") == ""
+  eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS"
 )
 
 nonspatial_slim <- tempfile()
@@ -70,7 +70,7 @@ tree
 #  ggtree(tree, branch.length = "none") %<+% labels +
 #    geom_label(aes(label = tskit_id))
 
-## ---- eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS" && Sys.getenv("R_HAS_GGTREE") != TRUE && Sys.getenv("RUNNER_OS") == ""----
+## ---- eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS" && Sys.getenv("R_HAS_GGTREE") != TRUE----
 library(ape)
 plot(tree, show.tip.label = FALSE)
 nodelabels()
